pub struct CachingCustomHandlerState<ExecC, QueryC> { /* private fields */ }Expand description
Internal state of CachingCustomHandler wrapping internal mutability so it is not exposed to
user. Those have to be shared internal state, as after mock is passed to app it is not
possible to access mock internals which are not exposed by API.
Implementations
sourceimpl<ExecC, QueryC> CachingCustomHandlerState<ExecC, QueryC>
impl<ExecC, QueryC> CachingCustomHandlerState<ExecC, QueryC>