ChecksumGenerator

Trait ChecksumGenerator 

pub trait ChecksumGenerator {
    // Required method
    fn checksum(&self, creator: &Addr, code_id: u64) -> Checksum;
}
This trait defines a method to calculate checksum based on the creator’s address and a unique code identifier.

Required Methods

fn checksum(&self, creator: &Addr, code_id: u64) -> Checksum

Calculates the checksum for a given contract’s code creator and code identifier. Returns a hexadecimal binary representation of the calculated checksum. There are no assumptions about the length of the calculated checksum.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors