IntoAddr

Trait IntoAddr 

pub trait IntoAddr {
    // Required methods
    fn into_addr(self) -> Addr;
    fn into_addr_with_prefix(self, prefix: &'static str) -> Addr;
}
Defines conversions to Addr, this conversion is format agnostic and should be aligned with the format generated by MockApi.

Required Methods

fn into_addr(self) -> Addr

Converts into Addr.

fn into_addr_with_prefix(self, prefix: &'static str) -> Addr

Converts into Addr with custom prefix.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoAddr for &str

Source

fn into_addr(self) -> Addr

Converts &str into Addr.

Source

fn into_addr_with_prefix(self, prefix: &'static str) -> Addr

Converts &str into Addr with custom prefix.

Implementors